package com.hzya.frame.plugin.lets.plugin.purchase;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.lang.Assert;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.hzya.frame.base.PluginBaseEntity;
import com.hzya.frame.beanutil.BeanUtil;
import com.hzya.frame.plugin.lets.constant.ProfilesActiveConstant;
import com.hzya.frame.plugin.lets.dao.*;
import com.hzya.frame.plugin.lets.entity.*;
import com.hzya.frame.plugin.lets.ofsvo.QueryOfsSoSaleOutVo;
import com.hzya.frame.plugin.lets.u8cdto.PoOrderChildrenDto;
import com.hzya.frame.plugin.lets.u8cdto.PoOrderParentChildrenDto;
import com.hzya.frame.plugin.lets.u8cdto.PoOrderParentDto;
import com.hzya.frame.plugin.lets.u8cdto.PoOrderSonDto;
import com.hzya.frame.plugin.lets.util.QueryBdBusitypeUtil;
import com.hzya.frame.ttxofs.dto.InterfaceParamDto;
import com.hzya.frame.ttxofs.dto.ofspoorder.OfsPoOrderBean;
import com.hzya.frame.ttxofs.dto.ofspoorder.OfsPoOrderData;
import com.hzya.frame.ttxofs.dto.ofspoorder.OfsPoOrderDetails;
import com.hzya.frame.ttxofs.dto.ofspoorder.OfsPoOrderHeader;
import com.hzya.frame.ttxofs.dto.stock.StockinOrderSearchResponse;
import com.hzya.frame.ttxofs.service.OfsUnifiedService;
import com.hzya.frame.web.entity.JsonResultEntity;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 代理品牌采购退货业务：（代理品牌采购退货）OFS销退出库单生成U8C红字采购订单
 *
 * @Author：liuyang
 * @Package：com.hzya.frame.plugin.lets.plugin.purchase
 * @Project：kangarooDataCenterV3
 * @name：ProxyPurchase
 * @Date：2024/8/19 18:01
 * @Filename：ProxyPurchase
 */
public class ProxyPurchaseReturn extends PluginBaseEntity {

    Logger logger = LoggerFactory.getLogger(ProxyPurchaseReturn.class);

    @Autowired
    private OfsUnifiedService ofsUnifiedService;

    @Autowired
    private QueryBdBusitypeUtil queryBdBusitypeUtil;

    @Autowired
    private IBdCorpDao iBdCorpDao;

    @Autowired
    private IBdDeptdocDao iBdDeptdocDao;

    @Autowired
    private IBdPurorgDao iBdPurorgDao;

    @Autowired
    private IBdCubasdocDao iBdCubasdocDao;

    @Autowired
    private IBdCumandocDao iBdCumandocDao;

    @Autowired
    private IBdInvmandocDao iBdInvmandocDao;

    @Override
    public void initialize() {
        logger.info(getPluginLabel() + "執行初始化方法initialize()");
    }

    @Override
    public void destroy() {
        logger.info(getPluginLabel() + "執行銷毀方法destroy()");
    }

    @Override
    public String getPluginId() {
        return "com.hzya.frame.plugin.lets.plugin.purchase.ProxyPurchaseReturn";
    }

    @Override
    public String getPluginName() {
        return "OFS销退出库单生成U8C红字采购订单(代理品牌采购退货)";
    }

    @Override
    public String getPluginLabel() {
        return "OFS销退出库单生成U8C红字采购订单(代理品牌采购退货)";
    }

    @Override
    public String getPluginType() {
        return "3";
    }

    @Override
    public JsonResultEntity executeBusiness(JSONObject requestJson) throws Exception {
        return null;
    }

    /**
     * 根据单号查询
     *
     * @author liuyang
     */
    public void startImplement(String code) {
        String threadNameStr = StrUtil.format("（代理品牌采购）OFS采购入库单生成U8C采购订单 售后入库单号", code);
        logger.info(threadNameStr);

        Thread thread = new Thread(new Runnable() {
            @Override
            public void run() {
                try {
                    List<StockinOrderSearchResponse.StockinOrder> returnGoodHeaderDetailsDataDtoArrayList = new ArrayList<>();
                    QueryOfsSoSaleOutVo queryOfsSoSaleOutVo = new QueryOfsSoSaleOutVo();
                    queryOfsSoSaleOutVo.setClientCode("LETS");
                    queryOfsSoSaleOutVo.setPageNo(1L);
                    queryOfsSoSaleOutVo.setPageSize(50L);
                    queryOfsSoSaleOutVo.setCode(code);
                    queryOfsSoSaleOutVo.setInternalInstructionType("PURCHASE_RETURN");
                    queryOfsSoSaleOutVo.setStatus(900L);
                    queryOfsReturnGoods(queryOfsSoSaleOutVo, returnGoodHeaderDetailsDataDtoArrayList, 1L);
                    logger.info("数据返回行数：{}", returnGoodHeaderDetailsDataDtoArrayList.size());
                    if (returnGoodHeaderDetailsDataDtoArrayList.size() > 0) {
                        getSet(returnGoodHeaderDetailsDataDtoArrayList);
                    } else {
                        logger.info("没有查询到任何数据！不需要同步");
                    }
                } catch (Exception e) {
                    logger.error("startImplement方法抛出异常", e);
                }
            }
        }, threadNameStr);
        thread.start();
        try {
            thread.join();
        } catch (Exception e) {
            logger.error("thread.join()异常", e);
        }
    }

    /**
     * 查询OFS售后退货入库单
     *
     * @param queryOfsSoSaleOutVo  查询参数
     * @param headerDetailsDtoList 查询结果集
     * @param pageNo               从第pageNo页开始查询
     */
    private void queryOfsReturnGoods(QueryOfsSoSaleOutVo queryOfsSoSaleOutVo, List<StockinOrderSearchResponse.StockinOrder> headerDetailsDtoList, Long pageNo) throws Exception {
        Long pageSize = 200L;
        queryOfsSoSaleOutVo.setPageNo(pageNo);
        queryOfsSoSaleOutVo.setPageSize(pageSize);

        InterfaceParamDto interfaceParamDto = new InterfaceParamDto();
        interfaceParamDto.setApi("ofs.shipment.search");
        interfaceParamDto.setData(JSON.toJSONString(queryOfsSoSaleOutVo));
        ofsUnifiedService.unified(interfaceParamDto);
    }

    /**
     * 环境预配置
     *
     * @param returnGoodHeaderDetailsDataDtoArrayList 采购入库单
     * @author liuyang
     */
    private void getSet(List<StockinOrderSearchResponse.StockinOrder> returnGoodHeaderDetailsDataDtoArrayList) throws Exception {
        //过滤成功的数据
        List<StockinOrderSearchResponse.StockinOrder> stockinOrderList = filterData(returnGoodHeaderDetailsDataDtoArrayList);
        //执行推送主逻辑
        implement(stockinOrderList);
    }

    /**
     * 过滤掉成功的数据
     *
     * @author liuyang
     */
    private List<StockinOrderSearchResponse.StockinOrder> filterData(List<StockinOrderSearchResponse.StockinOrder> returnGoodHeaderDetailsDataDtoArrayList) {
        List<StockinOrderSearchResponse.StockinOrder> headerDetailsDtoList1 = new ArrayList<>();
        if (returnGoodHeaderDetailsDataDtoArrayList != null && returnGoodHeaderDetailsDataDtoArrayList.size() > 0) {
            //TODO 出库单明细主键，需要O返回，目前没有，已经提需求
            headerDetailsDtoList1.addAll(returnGoodHeaderDetailsDataDtoArrayList);
        }
        return headerDetailsDtoList1;
    }

    /**
     * 执行主逻辑
     *
     * @author liuyang
     */
    private void implement(List<StockinOrderSearchResponse.StockinOrder> returnGoodHeaderDetailsDataDtoList) throws Exception {
        if (returnGoodHeaderDetailsDataDtoList != null && returnGoodHeaderDetailsDataDtoList.size() > 0) {
            try {
                // 查询基本档案
                List<PoOrderSonDto> poOrderSonDtos = queryBasicArchives(returnGoodHeaderDetailsDataDtoList);
                // 代理品牌采购业务流程
                BdBusitypeEntity bdBusitypeEntity = u8cOperationFlow();

                if (poOrderSonDtos != null && poOrderSonDtos.size() > 0) {
                    for (int i = 0; i < poOrderSonDtos.size(); i++) {
                        PoOrderSonDto poOrderSonDto = poOrderSonDtos.get(i);
                        List<StockinOrderSearchResponse.StockinOrder.StockinB> details = poOrderSonDto.getDetails();

                        //生成业务日期
                        String generateBusinessDate = createGenerateBusinessDate(poOrderSonDto);

                        BdCorpEntity bdCorpEntity = poOrderSonDto.getBdCorpEntity();//采购公司、收货公司
                        BdDeptdocEntity bdDeptdocEntity = poOrderSonDto.getBdDeptdocEntity();//采购部门
                        BdPurorgEntity bdPurorgEntity = poOrderSonDto.getBdPurorgEntity();//采购组织
                        BdCubasdocEntity bdCubasdocEntity = poOrderSonDto.getBdCubasdocEntity();
                        BdCumandocEntity bdCumandocEntity = poOrderSonDto.getBdCumandocEntity();//客商档案-供应商

                        OfsPoOrderData ofsPoOrderData = poOrderSonDto.getOfsPoOrderData();//OFS采购订单
                        OfsPoOrderHeader ofsPoOrderDataHeader = ofsPoOrderData.getHeader();
                        List<OfsPoOrderDetails> ofsPoOrderDataDetails = ofsPoOrderData.getDetails();

                        //采购订单表头
                        PoOrderParentDto poOrderParentDto = new PoOrderParentDto();
                        poOrderParentDto.setCbiztype(bdBusitypeEntity.getPkBusitype());//业务流程
                        poOrderParentDto.setCdeptid(bdDeptdocEntity.getPkDeptdoc());//采购部门
                        poOrderParentDto.setCoperator("0001A110000000000U3D");//制单人
                        poOrderParentDto.setCpurorganization(bdPurorgEntity.getPkPurorg());//采购组织
                        poOrderParentDto.setPk_corp(bdCorpEntity.getPkCorp());//采购公司
                        poOrderParentDto.setCvendormangid(bdCumandocEntity.getPkCumandoc());//供应商管理档案
                        poOrderParentDto.setDauditdate(generateBusinessDate);//审批日期
                        poOrderParentDto.setDorderdate(generateBusinessDate);//订单日期
                        poOrderParentDto.setDrevisiondate(generateBusinessDate);//修改日期

                        //采购订单明细行
                        List<PoOrderChildrenDto> poOrderChildrenDtoList = new ArrayList<>();

                        for (int j = 0; j < details.size(); j++) {
                            StockinOrderSearchResponse.StockinOrder.StockinB stockinB = details.get(j);

                            //2024年8月20日 16:02:21 已经和妮姐、万万确认，采购公司和收货公司目前是一致的，暂时不用区分取数逻辑
                            BdInvmandocEntity bdInvmandocEntity = queryInventoryMan(stockinB, bdCorpEntity.getPkCorp());
                            String receivedQty = stockinB.getReceivedQty();//实收数量

                            //原币含税单价
                            try {
//                                noriginalcurprice = noriginalcurtaxprice.divide(new BigDecimal(1).add(new BigDecimal(tax)), 20, BigDecimal.ROUND_HALF_UP).setScale(4, BigDecimal.ROUND_HALF_UP);
                            } catch (Exception e) {
                                logger.error("计算采购入库单原币含税单价失败", e);
                                Assert.state(false, "计算采购入库单原币含税单价失败 原因：{}", e.getMessage());
                            }


                            PoOrderChildrenDto poOrderChildrenDto = new PoOrderChildrenDto();
                            poOrderChildrenDto.setCmangid(bdInvmandocEntity.getPkInvmandoc());//存货管理id
                            poOrderChildrenDto.setNordernum(receivedQty);//订货数量
//                            poOrderChildrenDto.setNorgtaxprice();//原币含税单价
//                            poOrderChildrenDto.setPk_arrvcorp();//收货公司
//                            poOrderChildrenDto.setPk_arrvstoorg();//收货库存组织
//                            poOrderChildrenDto.setCwarehouseid();//收货仓库
                            poOrderChildrenDtoList.add(poOrderChildrenDto);

                            //2024年8月20日 16:00:03 已经和佳妮总确认，计划到货日期，不用进行传递
                        }

                        PoOrderParentChildrenDto poOrderParentChildrenDto = new PoOrderParentChildrenDto();
                        poOrderParentChildrenDto.setParentvo(poOrderParentDto);
                        poOrderParentChildrenDto.setChildrenvo(poOrderChildrenDtoList);

                    }
                } else {
                    logger.info("poOrderSonDto.size为0！");
                }
            } catch (Exception e) {
                logger.error("implement方法抛出异常", e);
            }
        }
    }

    /**
     * 档案转换
     *
     * @author liuyang
     */
    private List<PoOrderSonDto> queryBasicArchives(List<StockinOrderSearchResponse.StockinOrder> returnGoodHeaderDetailsDataDtoList) {
        List<PoOrderSonDto> poOrderSonDtoArrayList = new ArrayList<>();

        if (returnGoodHeaderDetailsDataDtoList != null && returnGoodHeaderDetailsDataDtoList.size() > 0) {
            try {
                for (int i = 0; i < returnGoodHeaderDetailsDataDtoList.size(); i++) {
                    StockinOrderSearchResponse.StockinOrder stockinOrder = returnGoodHeaderDetailsDataDtoList.get(i);
                    StockinOrderSearchResponse.StockinOrder.StockinH header = stockinOrder.getHeader();
                    List<StockinOrderSearchResponse.StockinOrder.StockinB> details = stockinOrder.getDetails();

                    //采购公司
                    String companyCode = header.getCompanyCode();
                    Assert.notNull(companyCode, "O表头公司不能为空");
                    BdCorpEntity bdCorpEntity = new BdCorpEntity();
                    bdCorpEntity.setDr(0);
                    bdCorpEntity.setDataSourceCode("lets_u8c");
                    bdCorpEntity.setUnitcode(companyCode);
                    List<BdCorpEntity> bdCorpEntityList = iBdCorpDao.query(bdCorpEntity);
                    if (bdCorpEntityList.size() == 0) {
                        Assert.state(false, "根据O货主编码{}，无法匹配到U8C销售公司", companyCode);
                    } else if (bdCorpEntityList.size() >= 2) {
                        Assert.state(false, "根据O货主编码{}，匹配到U8C销售公司{}个", companyCode, bdCorpEntityList.size());
                    }

                    //采购部门：其他
                    String deptName = "其他部门";
                    BdDeptdocEntity bdDeptdocEntity = new BdDeptdocEntity();
                    bdDeptdocEntity.setDataSourceCode("lets_u8c");
                    bdDeptdocEntity.setDr(0);
                    bdDeptdocEntity.setDeptname(deptName);
                    bdDeptdocEntity.setPkCorp(bdCorpEntityList.get(0).getPkCorp());
                    List<BdDeptdocEntity> bdDeptdocEntityList = iBdDeptdocDao.query(bdDeptdocEntity);
                    if (bdDeptdocEntityList.size() == 0) {
                        Assert.state(false, "根据部门名称：{} 公司id：{}，无法匹配到U8C销售组织", deptName, bdCorpEntityList.get(0).getPkCorp());
                    } else if (bdDeptdocEntityList.size() >= 2) {
                        Assert.state(false, "根据部门名称：{} 公司id：{}，匹配到U8C销售组织{}个", deptName, bdCorpEntityList.get(0).getPkCorp());
                    }

                    //采购组织
                    BdPurorgEntity bdPurorgEntity = new BdPurorgEntity();
                    bdPurorgEntity.setDr("0");
                    bdPurorgEntity.setDataSourceCode("lets_u8c");
                    bdPurorgEntity.setOwnercorp(bdCorpEntityList.get(0).getPkCorp());
                    List<BdPurorgEntity> bdPurorgEntityList = iBdPurorgDao.query(bdPurorgEntity);
                    if (bdPurorgEntityList.size() == 0) {
                        Assert.state(false, "根据采购公司主键：{} 无法匹配到采购组织", bdCorpEntityList.get(0).getPkCorp());
                    } else if (bdPurorgEntityList.size() >= 2) {
                        Assert.state(false, "根据采购公司主键：{} 匹配到多个采购组织", bdCorpEntityList.get(0).getPkCorp());
                    }

                    //客商基本档案(供应商类型)
                    //2024年8月20日 14:47:55 丽知商城、OFS 供应商客商档案、传递到U8C的客商，
                    //其中自定义项1作为原系统编码，因此统一传到自定义项一，已经和大家确认好了，没有关系的，放心大胆传吧，宝贝
                    String shipFromCode = header.getShipFromCode();
                    BdCubasdocEntity bdCubasdocEntity = new BdCubasdocEntity();
                    bdCubasdocEntity.setDataSourceCode("lets_u8c");
                    bdCubasdocEntity.setDr(0L);
                    bdCubasdocEntity.setDef1(shipFromCode);
                    List<BdCubasdocEntity> bdCubasdocEntityList = iBdCubasdocDao.query(bdCubasdocEntity);
                    if (bdCubasdocEntityList == null || bdCubasdocEntityList.size() == 0) {
                        Assert.state(false, "根据OFS供应商业务编码{}，无法查询到U8C客商档案信息(供应商)", shipFromCode);
                    } else if (bdCubasdocEntityList.size() >= 2) {
                        Assert.state(false, "根据OFS供应商业务编码{}，查询到多个U8C客商档案信息(供应商)", shipFromCode);
                    }

                    //客商管理档案
                    BdCumandocEntity bdCumandocEntity1 = new BdCumandocEntity();
                    bdCumandocEntity1.setDataSourceCode("lets_u8c");
                    bdCumandocEntity1.setDr(0L);
                    bdCumandocEntity1.setPkCorp(bdCorpEntityList.get(0).getPkCorp());
                    bdCumandocEntity1.setCustflags(ProfilesActiveConstant.SUPPLIER);
                    bdCumandocEntity1.setPkCubasdoc(bdCubasdocEntityList.get(0).getPkCubasdoc());
                    List<BdCumandocEntity> bdCumandocEntityList = iBdCumandocDao.query(bdCumandocEntity1);
                    if (bdCumandocEntityList == null || bdCumandocEntityList.size() == 0) {
                        Assert.state(false, "根据客商基本档案主键{}，无法匹配到客商管理档案", bdCubasdocEntityList.get(0).getPkCubasdoc());
                    } else if (bdCumandocEntityList.size() >= 2) {
                        Assert.state(false, "根据客商基本档案主键{}，匹配到多个客商管理档案", bdCubasdocEntityList.get(0).getPkCubasdoc());
                    }

                    //查询OFS采购订单
                    OfsPoOrderData ofsPoOrderData = queryOfsPoOrder(header.getRefOrderCode());

                    PoOrderSonDto poOrderSonDto = new PoOrderSonDto();
                    poOrderSonDto.setBdCorpEntity(bdCorpEntityList.get(0));
                    poOrderSonDto.setBdDeptdocEntity(bdDeptdocEntityList.get(0));
                    poOrderSonDto.setBdPurorgEntity(bdPurorgEntityList.get(0));
                    poOrderSonDto.setBdCubasdocEntity(bdCubasdocEntityList.get(0));
                    poOrderSonDto.setBdCumandocEntity(bdCumandocEntityList.get(0));
                    poOrderSonDto.setOfsPoOrderData(ofsPoOrderData);

                    BeanUtil.copyPropertiesV2(poOrderSonDto, header);
                    poOrderSonDtoArrayList.add(poOrderSonDto);
                }
                //成功
            } catch (Exception e) {
                logger.error("代理品牌采购入库单档案转换失败", e);
                //失败
            }
        } else {
            logger.info("queryBasicArchives对应returnGoodHeaderDetailsDataDtoList.size为0");
        }
        return poOrderSonDtoArrayList;
    }

    /**
     * 2024年8月6日 10:59:03 查询U8C业务流程
     *
     * @author liuyang
     */
    private BdBusitypeEntity u8cOperationFlow() throws Exception {
        //查询业务流程
        //2024年8月6日 11:33:07 具体的业务流程名称，还需要实施提供
        String processName = "代理品牌采购";
        BdBusitypeEntity bdBusitypeEntity = queryBdBusitypeUtil.queryBdBusitype(processName);
        Assert.notNull(bdBusitypeEntity, "根据业务流程名称({})没有查询到业务流程", processName);
        return bdBusitypeEntity;
    }

    /**
     * 2024年8月20日 15:46:10
     * 生成业务日期，以发货时间作为业务日期
     *
     * @author liuyang
     */
    private String createGenerateBusinessDate(PoOrderSonDto poOrderSonDto) {
        if (poOrderSonDto != null && poOrderSonDto.getShipAt() != null) {
            String shipAt = poOrderSonDto.getShipAt();
            String businessFormat = null;
            try {
                Date dbill = DateUtil.parse(shipAt);
                businessFormat = DateUtil.format(dbill, "yyyy-MM-dd");
            } catch (Exception e) {
                logger.error("业务日期生成失败", e);
            }
            return businessFormat;
        } else {
            logger.error("生成采购订单入库日期失败，或者shipAt为空! json：{}", JSON.toJSON(poOrderSonDto));
            Assert.state(false, "生成采购订单入库日期失败，或者shipAt为空! json：{}", JSON.toJSON(poOrderSonDto));
            return null;
        }
    }

    /**
     * 查询存货管理档案
     *
     * @param pkCorp   发货公司主键
     * @param stockinB 采购入库单明细行
     * @author liuyang
     */
    private BdInvmandocEntity queryInventoryMan(StockinOrderSearchResponse.StockinOrder.StockinB stockinB, String pkCorp) throws Exception {
        Assert.notNull(stockinB, "sonDetailsDto不能为空");
        Assert.notNull(stockinB.getSkuCode(), "O存货商家编码不能为空");
        Assert.notNull(pkCorp, "发货公司主键不能为空");

        BdInvmandocEntity bdInvmandocEntity = new BdInvmandocEntity();
        bdInvmandocEntity.setInvcode(stockinB.getSkuCode());
        bdInvmandocEntity.setPkCorp(pkCorp);
        List<BdInvmandocEntity> bdInvmandocEntity2 = iBdInvmandocDao.queryBdInvmandocByInvcodeList(bdInvmandocEntity);
        if (bdInvmandocEntity2.size() == 0) {
            Assert.state(false, "根据O商家编码：{} U8C发货公司主键：{}没有查询到存货管理档案", stockinB.getSkuCode(), pkCorp);
        } else if (bdInvmandocEntity2.size() >= 2) {
            Assert.state(false, "根据O商家编码：{} U8C发货公司主键：{}没有查询到存货管理档案", stockinB.getSkuCode(), pkCorp);
        }
        return bdInvmandocEntity2.get(0);
    }

    /**
     * 2024年8月20日 16:11:46
     *
     * @author liuyang
     */
    public OfsPoOrderData queryOfsPoOrder(String code) throws Exception {
        if (code != null && !"".equals(code)) {
            Long pageSize = 200L;
            Long pageNo = 1L;

            QueryOfsSoSaleOutVo queryOfsSoSaleOutVo = new QueryOfsSoSaleOutVo();
            queryOfsSoSaleOutVo.setPageNo(pageNo);
            queryOfsSoSaleOutVo.setPageSize(pageSize);
            queryOfsSoSaleOutVo.setCode(code);

            InterfaceParamDto interfaceParamDto = new InterfaceParamDto();
            interfaceParamDto.setApi("ofs.purchaseOrder.search");
            interfaceParamDto.setData(JSON.toJSONString(queryOfsSoSaleOutVo));
            OfsPoOrderBean ofsPoOrderBean = (OfsPoOrderBean) ofsUnifiedService.unified(interfaceParamDto);
            if (ofsPoOrderBean != null) {
                if ("false".equals(ofsPoOrderBean.getError()) && "0".equals(ofsPoOrderBean.getCode()) && "Success".equals(ofsPoOrderBean.getMsg())) {
                    List<OfsPoOrderData> data = ofsPoOrderBean.getData();
                    if (data != null && data.size() > 0) {
                        return data.get(0);
                    }
                } else {
                    logger.error("查询采购订单失败，失败原因:{}", JSON.toJSON(interfaceParamDto));
                }
            } else {
                logger.error("ofsPoOrderBean为空！interfaceParamDto接口入参：{}", JSON.toJSON(interfaceParamDto));
            }
        } else {
            Assert.state(false, "采购订单编码不能为空！");
        }
        return null;
    }

    /**
     * 2024年8月20日 16:42:14
     * 查找对应的采购订单明细行
     * 2024年8月20日 17:42:15
     * 应该通过明细行主键匹配，但是只能根据sku匹配目前的实现逻辑
     *
     * @param ofsPoOrderDataDetails OFS采购订单明细行所有对象
     * @param stockinB              OFS采购入库单明细行对象
     * @author liuyang
     */
    private void findOfsPoOrderDetail(List<OfsPoOrderDetails> ofsPoOrderDataDetails, StockinOrderSearchResponse.StockinOrder.StockinB stockinB) {
        if (ofsPoOrderDataDetails != null && ofsPoOrderDataDetails.size() > 0 && stockinB != null) {

        }
    }
}