package com.hzya.frame.plugin.lets.plugin.purchase;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.lang.Assert;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpRequest;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.hzya.frame.base.PluginBaseEntity;
import com.hzya.frame.beanutil.BeanUtil;
import com.hzya.frame.plugin.lets.constant.ProfilesActiveConstant;
import com.hzya.frame.plugin.lets.dao.*;
import com.hzya.frame.plugin.lets.entity.*;
import com.hzya.frame.plugin.lets.ofsvo.QueryOfsSoSaleOutVo;
import com.hzya.frame.plugin.lets.u8cdto.*;
import com.hzya.frame.plugin.lets.util.QueryBdBusitypeUtil;
import com.hzya.frame.ttxofs.dto.InterfaceParamDto;
import com.hzya.frame.ttxofs.dto.ofspoorder.OfsPoOrderBean;
import com.hzya.frame.ttxofs.dto.ofspoorder.OfsPoOrderData;
import com.hzya.frame.ttxofs.dto.ofspoorder.OfsPoOrderDetails;
import com.hzya.frame.ttxofs.dto.ofspoorder.OfsPoOrderHeader;
import com.hzya.frame.ttxofs.dto.stock.StockinOrderSearchResponse;
import com.hzya.frame.ttxofs.service.OfsUnifiedService;
import com.hzya.frame.web.entity.JsonResultEntity;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;

import java.math.BigDecimal;
import java.util.*;

/**
 * 代理品牌采购业务：（代理品牌采购）OFS采购入库单生成U8C采购订单
 *
 * @Author：liuyang
 * @Package：com.hzya.frame.plugin.lets.plugin.purchase
 * @Project：kangarooDataCenterV3
 * @name：ProxyPurchase
 * @Date：2024/8/19 18:01
 * @Filename：ProxyPurchase
 */
public class ProxyPurchaseWarehous extends PluginBaseEntity {

    Logger logger = LoggerFactory.getLogger(ProxyPurchaseWarehous.class);

    @Autowired
    private OfsUnifiedService ofsUnifiedService;

    @Autowired
    private QueryBdBusitypeUtil queryBdBusitypeUtil;

    @Autowired
    private IBdCorpDao iBdCorpDao;

    @Autowired
    private IBdDeptdocDao iBdDeptdocDao;

    @Autowired
    private IBdPurorgDao iBdPurorgDao;

    @Autowired
    private IBdCubasdocDao iBdCubasdocDao;

    @Autowired
    private IBdCumandocDao iBdCumandocDao;

    @Autowired
    private IBdInvmandocDao iBdInvmandocDao;

    @Autowired
    private IBdCalbodyDao iBdCalbodyDao;

    @Autowired
    private IBdStordocDao iBdStordocDao;

    @Override
    public void initialize() {
        logger.info(getPluginLabel() + "執行初始化方法initialize()");
    }

    @Override
    public void destroy() {
        logger.info(getPluginLabel() + "執行銷毀方法destroy()");
    }

    @Override
    public String getPluginId() {
        return "com.hzya.frame.plugin.lets.plugin.purchase.ProxyPurchaseWarehous";
    }

    @Override
    public String getPluginName() {
        return "OFS采购入库单生成U8C采购订单(代理品牌)";
    }

    @Override
    public String getPluginLabel() {
        return "OFS采购入库单生成U8C采购订单(代理品牌)";
    }

    @Override
    public String getPluginType() {
        return "3";
    }

    @Override
    public JsonResultEntity executeBusiness(JSONObject requestJson) throws Exception {
        return null;
    }

    /**
     * 根据单号查询
     *
     * @author liuyang
     */
    public void startImplement(String code) {
        String threadNameStr = StrUtil.format("（代理品牌采购）OFS采购入库单生成U8C采购订单 售后入库单号", code);
        logger.info(threadNameStr);

        Thread thread = new Thread(new Runnable() {
            @Override
            public void run() {
                try {
                    List<StockinOrderSearchResponse.StockinOrder> returnGoodHeaderDetailsDataDtoArrayList = new ArrayList<>();
                    QueryOfsSoSaleOutVo queryOfsSoSaleOutVo = new QueryOfsSoSaleOutVo();
                    queryOfsSoSaleOutVo.setClientCode("LETS");
                    queryOfsSoSaleOutVo.setPageNo(1L);
                    queryOfsSoSaleOutVo.setPageSize(50L);
                    queryOfsSoSaleOutVo.setCode(code);
                    queryOfsSoSaleOutVo.setInternalInstructionType("PURCHASE");
                    queryOfsSoSaleOutVo.setStatus(900L);
                    queryOfsReturnGoods(queryOfsSoSaleOutVo, returnGoodHeaderDetailsDataDtoArrayList, 1L);
                    logger.info("数据返回行数：{}", returnGoodHeaderDetailsDataDtoArrayList.size());
                    if (returnGoodHeaderDetailsDataDtoArrayList.size() > 0) {
                        getSet(returnGoodHeaderDetailsDataDtoArrayList);
                    } else {
                        logger.info("没有查询到任何数据！不需要同步");
                    }
                } catch (Exception e) {
                    logger.error("startImplement方法抛出异常", e);
                }
            }
        }, threadNameStr);
        thread.start();
        try {
            thread.join();
        } catch (Exception e) {
            logger.error("thread.join()异常", e);
        }
    }

    /**
     * 查询OFS售后退货入库单
     *
     * @param queryOfsSoSaleOutVo  查询参数
     * @param headerDetailsDtoList 查询结果集
     * @param pageNo               从第pageNo页开始查询
     */
    private void queryOfsReturnGoods(QueryOfsSoSaleOutVo queryOfsSoSaleOutVo, List<StockinOrderSearchResponse.StockinOrder> headerDetailsDtoList, Long pageNo) throws Exception {
        Long pageSize = 200L;
        queryOfsSoSaleOutVo.setPageNo(pageNo);
        queryOfsSoSaleOutVo.setPageSize(pageSize);

        InterfaceParamDto interfaceParamDto = new InterfaceParamDto();
        interfaceParamDto.setApi("ofs.receipt.search");
        interfaceParamDto.setData(JSON.toJSONString(queryOfsSoSaleOutVo));
        StockinOrderSearchResponse rertunGoodsRootBean = (StockinOrderSearchResponse) ofsUnifiedService.unified(interfaceParamDto);
        if (rertunGoodsRootBean != null) {
            if ("false".equals(rertunGoodsRootBean.getError()) && "0".equals(rertunGoodsRootBean.getCode()) && "Success".equals(rertunGoodsRootBean.getMsg())) {
                List<StockinOrderSearchResponse.StockinOrder> stockinOrderList = rertunGoodsRootBean.getData();
                if (stockinOrderList != null && stockinOrderList.size() > 0) {
                    headerDetailsDtoList.addAll(stockinOrderList);

                    //TODO OFS没有提供分页字段，等待开发
                }
            } else {
                logger.error("查询失败，失败原因:{}", JSON.toJSON(interfaceParamDto));
            }
        } else {
            logger.error("rertunGoodsRootBean为空！interfaceParamDto对象的结果集json：{}", JSON.toJSON(interfaceParamDto));
        }
    }

    /**
     * 环境预配置
     *
     * @param returnGoodHeaderDetailsDataDtoArrayList 采购入库单
     * @author liuyang
     */
    private void getSet(List<StockinOrderSearchResponse.StockinOrder> returnGoodHeaderDetailsDataDtoArrayList) throws Exception {
        //过滤成功的数据
        List<StockinOrderSearchResponse.StockinOrder> stockinOrderList = filterData(returnGoodHeaderDetailsDataDtoArrayList);
        //执行推送主逻辑
        implement(stockinOrderList);
    }

    /**
     * 过滤掉成功的数据
     *
     * @author liuyang
     */
    private List<StockinOrderSearchResponse.StockinOrder> filterData(List<StockinOrderSearchResponse.StockinOrder> returnGoodHeaderDetailsDataDtoArrayList) {
        List<StockinOrderSearchResponse.StockinOrder> headerDetailsDtoList1 = new ArrayList<>();
        if (returnGoodHeaderDetailsDataDtoArrayList != null && returnGoodHeaderDetailsDataDtoArrayList.size() > 0) {
            //TODO 出库单明细主键，需要O返回，目前没有，已经提需求
            headerDetailsDtoList1.addAll(returnGoodHeaderDetailsDataDtoArrayList);
        }
        return headerDetailsDtoList1;
    }

    /**
     * 执行主逻辑
     *
     * @author liuyang
     */
    private void implement(List<StockinOrderSearchResponse.StockinOrder> returnGoodHeaderDetailsDataDtoList) throws Exception {
        if (returnGoodHeaderDetailsDataDtoList != null && returnGoodHeaderDetailsDataDtoList.size() > 0) {
            try {
                // 查询基本档案
                List<PoOrderSonDto> poOrderSonDtos = queryBasicArchives(returnGoodHeaderDetailsDataDtoList);
                // 代理品牌采购业务流程
                BdBusitypeEntity bdBusitypeEntity = u8cOperationFlow();

                if (poOrderSonDtos != null && poOrderSonDtos.size() > 0) {
                    for (int i = 0; i < poOrderSonDtos.size(); i++) {
                        PoOrderSonDto poOrderSonDto = poOrderSonDtos.get(i);
                        List<StockinOrderSearchResponse.StockinOrder.StockinB> details = poOrderSonDto.getDetails();

                        //生成业务日期
                        String generateBusinessDate = createGenerateBusinessDate(poOrderSonDto);

                        BdCorpEntity bdCorpEntity = poOrderSonDto.getBdCorpEntity();//采购公司、收货公司
                        BdDeptdocEntity bdDeptdocEntity = poOrderSonDto.getBdDeptdocEntity();//采购部门
                        BdPurorgEntity bdPurorgEntity = poOrderSonDto.getBdPurorgEntity();//采购组织
                        BdCubasdocEntity bdCubasdocEntity = poOrderSonDto.getBdCubasdocEntity();
                        BdCumandocEntity bdCumandocEntity = poOrderSonDto.getBdCumandocEntity();//客商档案-供应商
                        BdCalbodyEntity bdCalbodyEntity = poOrderSonDto.getBdCalbodyEntity();//收货库存组织
                        BdStordocEntity bdStordocEntity = poOrderSonDto.getBdStordocEntity();//收货仓库

                        OfsPoOrderData ofsPoOrderData = poOrderSonDto.getOfsPoOrderData();//OFS采购订单
                        OfsPoOrderHeader ofsPoOrderDataHeader = ofsPoOrderData.getHeader();
                        List<OfsPoOrderDetails> ofsPoOrderDataDetails = ofsPoOrderData.getDetails();

                        //采购订单表头
                        PoOrderParentDto poOrderParentDto = new PoOrderParentDto();
                        poOrderParentDto.setCbiztype(bdBusitypeEntity.getPkBusitype());//业务流程
                        poOrderParentDto.setCdeptid(bdDeptdocEntity.getPkDeptdoc());//采购部门
                        poOrderParentDto.setCoperator("0001A110000000000U3D");//制单人
                        poOrderParentDto.setCpurorganization(bdPurorgEntity.getPkPurorg());//采购组织
                        poOrderParentDto.setPk_corp(bdCorpEntity.getPkCorp());//采购公司
                        poOrderParentDto.setCvendormangid(bdCumandocEntity.getPkCumandoc());//供应商管理档案
                        poOrderParentDto.setDauditdate(generateBusinessDate);//审批日期
                        poOrderParentDto.setDorderdate(generateBusinessDate);//订单日期
                        poOrderParentDto.setDrevisiondate(generateBusinessDate);//修改日期

                        //采购订单明细行
                        List<PoOrderChildrenDto> poOrderChildrenDtoList = new ArrayList<>();

                        for (int j = 0; j < details.size(); j++) {
                            StockinOrderSearchResponse.StockinOrder.StockinB stockinB = details.get(j);
                            OfsPoOrderDetails ofsPoOrderDetail = findOfsPoOrderDetail(ofsPoOrderDataDetails, stockinB);

                            //2024年8月20日 16:02:21 已经和妮姐、万万确认，采购公司和收货公司目前是一致的，暂时不用区分取数逻辑
                            BdInvmandocEntity bdInvmandocEntity = queryInventoryMan(stockinB, bdCorpEntity.getPkCorp());
                            String receivedQty = stockinB.getReceivedQty();//实收数量
                            String fulfillAmount = ofsPoOrderDetail.getFulfillAmount();//实收累计总金额

                            //原币含税单价
                            BigDecimal noriginalcurprice = null;
                            try {
                                noriginalcurprice = new BigDecimal(fulfillAmount).divide(new BigDecimal(receivedQty), 20, BigDecimal.ROUND_HALF_UP).setScale(4, BigDecimal.ROUND_HALF_UP);
                            } catch (Exception e) {
                                logger.error("计算采购入库单原币含税单价失败", e);
                                Assert.state(false, "计算采购入库单原币含税单价失败 原因：{}", e.getMessage());
                            }

                            PoOrderChildrenDto poOrderChildrenDto = new PoOrderChildrenDto();
                            poOrderChildrenDto.setCmangid(bdInvmandocEntity.getPkInvmandoc());//存货管理id
                            poOrderChildrenDto.setNordernum(receivedQty);//订货数量
                            poOrderChildrenDto.setNorgtaxprice(noriginalcurprice.stripTrailingZeros().toPlainString());//原币含税单价
                            poOrderChildrenDto.setPk_arrvcorp(bdCorpEntity.getPkCorp());//收货公司
                            poOrderChildrenDto.setPk_arrvstoorg(bdCalbodyEntity.getPkCalbody());//收货库存组织
                            poOrderChildrenDto.setCwarehouseid(bdStordocEntity.getPkStordoc());//收货仓库
                            poOrderChildrenDtoList.add(poOrderChildrenDto);

                            //2024年8月20日 16:00:03 已经和佳妮总确认，计划到货日期，不用进行传递
                        }

                        List<PoOrderParentChildrenDto> poOrderParentChildrenDtoList = new ArrayList<>();
                        PoOrderParentChildrenDto poOrderParentChildrenDto = new PoOrderParentChildrenDto();
                        poOrderParentChildrenDto.setParentvo(poOrderParentDto);
                        poOrderParentChildrenDto.setChildrenvo(poOrderChildrenDtoList);
                        poOrderParentChildrenDtoList.add(poOrderParentChildrenDto);

                        Map<String, List<PoOrderParentChildrenDto>> stringStringMap = new HashMap<>();
                        stringStringMap.put("puordervo", poOrderParentChildrenDtoList);
                        sendU8CPoOrder(JSON.toJSONString(stringStringMap));
                        logger.info("推送U8C代理品牌采购订单采购！采购订单主键：{} 采购订单编码：{}", null, null);
                    }
                } else {
                    logger.info("poOrderSonDto.size为0！");
                }
            } catch (Exception e) {
                logger.error("implement方法抛出异常", e);
            }
        }
    }

    /**
     * 档案转换
     *
     * @author liuyang
     */
    private List<PoOrderSonDto> queryBasicArchives(List<StockinOrderSearchResponse.StockinOrder> returnGoodHeaderDetailsDataDtoList) {
        List<PoOrderSonDto> poOrderSonDtoArrayList = new ArrayList<>();

        if (returnGoodHeaderDetailsDataDtoList != null && returnGoodHeaderDetailsDataDtoList.size() > 0) {
            try {
                for (int i = 0; i < returnGoodHeaderDetailsDataDtoList.size(); i++) {
                    StockinOrderSearchResponse.StockinOrder stockinOrder = returnGoodHeaderDetailsDataDtoList.get(i);
                    StockinOrderSearchResponse.StockinOrder.StockinH header = stockinOrder.getHeader();
                    List<StockinOrderSearchResponse.StockinOrder.StockinB> details = stockinOrder.getDetails();

                    //采购公司
                    String companyCode = header.getCompanyCode();
                    Assert.notNull(companyCode, "O表头公司不能为空");
                    BdCorpEntity bdCorpEntity = new BdCorpEntity();
                    bdCorpEntity.setDr(0);
                    bdCorpEntity.setDataSourceCode("lets_u8c");
                    bdCorpEntity.setUnitcode(companyCode);
                    List<BdCorpEntity> bdCorpEntityList = iBdCorpDao.query(bdCorpEntity);
                    if (bdCorpEntityList.size() == 0) {
                        Assert.state(false, "根据O货主编码{}，无法匹配到U8C销售公司", companyCode);
                    } else if (bdCorpEntityList.size() >= 2) {
                        Assert.state(false, "根据O货主编码{}，匹配到U8C销售公司{}个", companyCode, bdCorpEntityList.size());
                    }

                    //采购部门：其他
                    String deptName = "其他部门";
                    BdDeptdocEntity bdDeptdocEntity = new BdDeptdocEntity();
                    bdDeptdocEntity.setDataSourceCode("lets_u8c");
                    bdDeptdocEntity.setDr(0);
                    bdDeptdocEntity.setDeptname(deptName);
                    bdDeptdocEntity.setPkCorp(bdCorpEntityList.get(0).getPkCorp());
                    List<BdDeptdocEntity> bdDeptdocEntityList = iBdDeptdocDao.query(bdDeptdocEntity);
                    if (bdDeptdocEntityList.size() == 0) {
                        Assert.state(false, "根据部门名称：{} 公司id：{}，无法匹配到U8C销售组织", deptName, bdCorpEntityList.get(0).getPkCorp());
                    } else if (bdDeptdocEntityList.size() >= 2) {
                        Assert.state(false, "根据部门名称：{} 公司id：{}，匹配到U8C销售组织{}个", deptName, bdCorpEntityList.get(0).getPkCorp());
                    }

                    //采购组织
                    BdPurorgEntity bdPurorgEntity = new BdPurorgEntity();
                    bdPurorgEntity.setDr("0");
                    bdPurorgEntity.setDataSourceCode("lets_u8c");
                    bdPurorgEntity.setOwnercorp(bdCorpEntityList.get(0).getPkCorp());
                    List<BdPurorgEntity> bdPurorgEntityList = iBdPurorgDao.query(bdPurorgEntity);
                    if (bdPurorgEntityList.size() == 0) {
                        Assert.state(false, "根据采购公司主键：{} 无法匹配到采购组织", bdCorpEntityList.get(0).getPkCorp());
                    } else if (bdPurorgEntityList.size() >= 2) {
                        Assert.state(false, "根据采购公司主键：{} 匹配到多个采购组织", bdCorpEntityList.get(0).getPkCorp());
                    }

                    //客商基本档案(供应商类型)
                    //2024年8月20日 14:47:55 丽知商城、OFS 供应商客商档案、传递到U8C的客商，
                    //其中自定义项1作为原系统编码，因此统一传到自定义项一，已经和大家确认好了，没有关系的，放心大胆传吧，宝贝
                    String shipFromCode = header.getShipFromCode();
                    BdCubasdocEntity bdCubasdocEntity = new BdCubasdocEntity();
                    bdCubasdocEntity.setDataSourceCode("lets_u8c");
                    bdCubasdocEntity.setDr(0L);
                    bdCubasdocEntity.setDef1(shipFromCode);
                    List<BdCubasdocEntity> bdCubasdocEntityList = iBdCubasdocDao.query(bdCubasdocEntity);
                    if (bdCubasdocEntityList == null || bdCubasdocEntityList.size() == 0) {
                        Assert.state(false, "根据OFS供应商业务编码{}，无法查询到U8C客商档案信息(供应商)", shipFromCode);
                    } else if (bdCubasdocEntityList.size() >= 2) {
                        Assert.state(false, "根据OFS供应商业务编码{}，查询到多个U8C客商档案信息(供应商)", shipFromCode);
                    }

                    //客商管理档案
                    BdCumandocEntity bdCumandocEntity1 = new BdCumandocEntity();
                    bdCumandocEntity1.setDataSourceCode("lets_u8c");
                    bdCumandocEntity1.setDr(0L);
                    bdCumandocEntity1.setPkCorp(bdCorpEntityList.get(0).getPkCorp());
                    bdCumandocEntity1.setCustflags(ProfilesActiveConstant.SUPPLIER);
                    bdCumandocEntity1.setPkCubasdoc(bdCubasdocEntityList.get(0).getPkCubasdoc());
                    List<BdCumandocEntity> bdCumandocEntityList = iBdCumandocDao.query(bdCumandocEntity1);
                    if (bdCumandocEntityList == null || bdCumandocEntityList.size() == 0) {
                        Assert.state(false, "根据客商基本档案主键{}，无法匹配到客商管理档案", bdCubasdocEntityList.get(0).getPkCubasdoc());
                    } else if (bdCumandocEntityList.size() >= 2) {
                        Assert.state(false, "根据客商基本档案主键{}，匹配到多个客商管理档案", bdCubasdocEntityList.get(0).getPkCubasdoc());
                    }

                    // 2024年8月20日 23:51:56 收货库存组织，应该是通过收货公司查询得出收货库存组织，目前收货公司和采购公司保持一致，那么就以采购公司带出！这个逻辑已经和佳妮确认
                    BdCalbodyEntity bdCalbodyEntity = new BdCalbodyEntity();
                    bdCalbodyEntity.setDr(0);
                    bdCalbodyEntity.setDataSourceCode("lets_u8c");
                    bdCalbodyEntity.setPkCorp(bdCorpEntityList.get(0).getPkCorp());
                    List<BdCalbodyEntity> bdCalbodyEntities = iBdCalbodyDao.query(bdCalbodyEntity);
                    if (bdCalbodyEntities.size() == 0) {
                        Assert.state(false, "根据U8C采购公司{}，无法匹配到U8C发货库存组织", bdCorpEntityList.get(0).getPkCorp());
                    } else if (bdCalbodyEntities.size() >= 2) {
                        Assert.state(false, "根据U8C采购公司{}，匹配到U8C发货库存组织{}个", bdCorpEntityList.get(0).getPkCorp(), bdCalbodyEntities.size());
                    }

                    //收货仓库
                    String facilityCode = header.getFacilityCode();
                    Assert.notNull(facilityCode, "O售后入库单仓库facilityCode字段不能为空");
                    BdStordocEntity bdStordocEntity = new BdStordocEntity();
                    bdStordocEntity.setDr(0L);
                    bdStordocEntity.setDataSourceCode("lets_u8c");
                    bdStordocEntity.setPkCalbody(bdCalbodyEntities.get(0).getPkCalbody());
                    bdStordocEntity.setStorcode(facilityCode);
                    List<BdStordocEntity> bdStordocEntityList = iBdStordocDao.query(bdStordocEntity);
                    if (bdStordocEntityList.size() == 0) {
                        Assert.state(false, "根据O仓库编码+U8C收货库存组织主键，无法匹配到U8C仓库", facilityCode, bdCalbodyEntities.get(0).getPkCalbody());
                    } else if (bdStordocEntityList.size() >= 2) {
                        Assert.state(false, "根据O仓库编码+U8C收货库存组织主键，匹配到U8C仓库多个", facilityCode, bdCalbodyEntities.get(0).getPkCalbody());
                    }

                    //查询OFS采购订单
                    OfsPoOrderData ofsPoOrderData = queryOfsPoOrder(header.getRefOrderCode());

                    PoOrderSonDto poOrderSonDto = new PoOrderSonDto();
                    poOrderSonDto.setBdCorpEntity(bdCorpEntityList.get(0));
                    poOrderSonDto.setBdDeptdocEntity(bdDeptdocEntityList.get(0));
                    poOrderSonDto.setBdPurorgEntity(bdPurorgEntityList.get(0));
                    poOrderSonDto.setBdCubasdocEntity(bdCubasdocEntityList.get(0));
                    poOrderSonDto.setBdCumandocEntity(bdCumandocEntityList.get(0));
                    poOrderSonDto.setOfsPoOrderData(ofsPoOrderData);
                    poOrderSonDto.setBdCalbodyEntity(bdCalbodyEntities.get(0));
                    poOrderSonDto.setBdStordocEntity(bdStordocEntityList.get(0));

                    BeanUtil.copyPropertiesV2(poOrderSonDto, header);
                    poOrderSonDtoArrayList.add(poOrderSonDto);
                }
                //成功
            } catch (Exception e) {
                logger.error("代理品牌采购入库单档案转换失败", e);
                //失败
            }
        } else {
            logger.info("queryBasicArchives对应returnGoodHeaderDetailsDataDtoList.size为0");
        }
        return poOrderSonDtoArrayList;
    }

    /**
     * 2024年8月6日 10:59:03 查询U8C业务流程
     *
     * @author liuyang
     */
    private BdBusitypeEntity u8cOperationFlow() throws Exception {
        //查询业务流程
        //2024年8月6日 11:33:07 具体的业务流程名称，还需要实施提供
        String processName = "代理品牌采购";
        BdBusitypeEntity bdBusitypeEntity = queryBdBusitypeUtil.queryBdBusitype(processName);
        Assert.notNull(bdBusitypeEntity, "根据业务流程名称({})没有查询到业务流程", processName);
        return bdBusitypeEntity;
    }

    /**
     * 2024年8月20日 15:46:10
     * 生成业务日期，以发货时间作为业务日期
     *
     * @author liuyang
     */
    private String createGenerateBusinessDate(PoOrderSonDto poOrderSonDto) {
        if (poOrderSonDto != null && poOrderSonDto.getShipAt() != null) {
            String shipAt = poOrderSonDto.getShipAt();
            String businessFormat = null;
            try {
                Date dbill = DateUtil.parse(shipAt);
                businessFormat = DateUtil.format(dbill, "yyyy-MM-dd");
            } catch (Exception e) {
                logger.error("业务日期生成失败", e);
            }
            return businessFormat;
        } else {
            logger.error("生成采购订单入库日期失败，或者shipAt为空! json：{}", JSON.toJSON(poOrderSonDto));
            Assert.state(false, "生成采购订单入库日期失败，或者shipAt为空! json：{}", JSON.toJSON(poOrderSonDto));
            return null;
        }
    }

    /**
     * 查询存货管理档案
     *
     * @param pkCorp   发货公司主键
     * @param stockinB 采购入库单明细行
     * @author liuyang
     */
    private BdInvmandocEntity queryInventoryMan(StockinOrderSearchResponse.StockinOrder.StockinB stockinB, String pkCorp) throws Exception {
        Assert.notNull(stockinB, "sonDetailsDto不能为空");
        Assert.notNull(stockinB.getSkuCode(), "O存货商家编码不能为空");
        Assert.notNull(pkCorp, "发货公司主键不能为空");

        BdInvmandocEntity bdInvmandocEntity = new BdInvmandocEntity();
        bdInvmandocEntity.setInvcode(stockinB.getSkuCode());
        bdInvmandocEntity.setPkCorp(pkCorp);
        List<BdInvmandocEntity> bdInvmandocEntity2 = iBdInvmandocDao.queryBdInvmandocByInvcodeList(bdInvmandocEntity);
        if (bdInvmandocEntity2.size() == 0) {
            Assert.state(false, "根据O商家编码：{} U8C发货公司主键：{}没有查询到存货管理档案", stockinB.getSkuCode(), pkCorp);
        } else if (bdInvmandocEntity2.size() >= 2) {
            Assert.state(false, "根据O商家编码：{} U8C发货公司主键：{}没有查询到存货管理档案", stockinB.getSkuCode(), pkCorp);
        }
        return bdInvmandocEntity2.get(0);
    }

    /**
     * 2024年8月20日 16:11:46
     *
     * @author liuyang
     */
    public OfsPoOrderData queryOfsPoOrder(String code) throws Exception {
        if (code != null && !"".equals(code)) {
            Long pageSize = 200L;
            Long pageNo = 1L;

            QueryOfsSoSaleOutVo queryOfsSoSaleOutVo = new QueryOfsSoSaleOutVo();
            queryOfsSoSaleOutVo.setPageNo(pageNo);
            queryOfsSoSaleOutVo.setPageSize(pageSize);
            queryOfsSoSaleOutVo.setCode(code);

            InterfaceParamDto interfaceParamDto = new InterfaceParamDto();
            interfaceParamDto.setApi("ofs.purchaseOrder.search");
            interfaceParamDto.setData(JSON.toJSONString(queryOfsSoSaleOutVo));
            OfsPoOrderBean ofsPoOrderBean = (OfsPoOrderBean) ofsUnifiedService.unified(interfaceParamDto);
            if (ofsPoOrderBean != null) {
                if ("false".equals(ofsPoOrderBean.getError()) && "0".equals(ofsPoOrderBean.getCode()) && "Success".equals(ofsPoOrderBean.getMsg())) {
                    List<OfsPoOrderData> data = ofsPoOrderBean.getData();
                    if (data != null && data.size() > 0) {
                        return data.get(0);
                    }
                } else {
                    logger.error("查询采购订单失败，失败原因:{}", JSON.toJSON(interfaceParamDto));
                }
            } else {
                logger.error("ofsPoOrderBean为空！interfaceParamDto接口入参：{}", JSON.toJSON(interfaceParamDto));
            }
        } else {
            Assert.state(false, "采购订单编码不能为空！");
        }
        return null;
    }

    /**
     * 2024年8月20日 16:42:14
     * 查找对应的采购订单明细行
     * 2024年8月20日 17:42:15
     * 应该通过明细行主键匹配，但是只能根据sku匹配目前的实现逻辑
     * 查找OFS采购订单明细行，主要是为了带出实付金额，通过实付金额/实收数量=含税单价
     *
     * @param ofsPoOrderDataDetails OFS采购订单明细行所有对象
     * @param stockinB              OFS采购入库单明细行对象
     * @author liuyang
     */
    private OfsPoOrderDetails findOfsPoOrderDetail(List<OfsPoOrderDetails> ofsPoOrderDataDetails, StockinOrderSearchResponse.StockinOrder.StockinB stockinB) {
        if (ofsPoOrderDataDetails != null && ofsPoOrderDataDetails.size() > 0 && stockinB != null) {
            //TODO 2024年8月20日 23:33:11 先使用sku验证，然后O接口更新明细id，使用明细id匹配！
            // 2024年8月20日 23:36:04 使用sku匹配，在某种角度来说是错误的
            for (int i = 0; i < ofsPoOrderDataDetails.size(); i++) {
                if (ofsPoOrderDataDetails.get(i).getSkuCode().equals(stockinB.getSkuCode())) {
                    return ofsPoOrderDataDetails.get(0);
                }
            }
        } else {
            logger.error("findOfsPoOrderDetail方法对应的ofsPoOrderDataDetails不能为空！否则业务目标无法完成！");
        }
        Assert.state(false, "无法匹配到采购订单明细行，业务逻辑无法完成，根据sku编码：{}查找，但是在采购订单中无法匹配！", stockinB.getSkuCode());
        return null;
    }

    /**
     * 2024年8月20日 23:58:13
     * 推送U8C采购订单
     *
     * @author liuyang
     */
    public SoSaleResultRootDto sendU8CPoOrder(String param) throws Exception {
        long startLong = System.currentTimeMillis();
        logger.info("代理品牌采购推送开始，推送参数：" + param + ",U8C_URL:" + ProfilesActiveConstant.U8C_URL);
        String result = HttpRequest.post(ProfilesActiveConstant.U8C_URL).header("appId", "800037")//头信息，多个头信息多次调用此方法即可
                .header("usercode", "admin").header("password", "21232f297a57a5a743894a0e4a801fc3").header("system", "lz").header("trantype", "PK").header("apiCode", "8000370004")//头信息，多个头信息多次调用此方法即可
                .header("publicKey", "ZJYAWb7lhAUTYqekPkU+uHJv1/ObJxb7dT7sD8HPRDGAgyhCe7eDIk+3zDUT+v578prj")//头信息，多个头信息多次调用此方法即可
                .header("secretKey", "fviZnLBsQUAGF8w8FSOdJi7XlIm/XAZclMxRagDLfTyJFlvnIBF3w66Hrpfzs8cYj3JzOP8MtA1LSGvL+2BWG8c/o7DKi92S4mr3zcGearA=")//头信息，多个头信息多次调用此方法即可
                .body(param)//表单内容
                .timeout(20000)//超时，毫秒
                .execute().body();
        logger.info("代理品牌采购推送结束，返回参数：" + result);
        long endLong = System.currentTimeMillis();
        logger.info("U8C采购订单接口请求耗时：" + (endLong - startLong));

        JSONObject jsonObject = JSON.parseObject(result);
        result = String.valueOf(jsonObject.get("attribute"));

        boolean isSuccess = false;
        SoSaleResultRootDto soSaleResultRootDto = null;
        if (result != null && !"".equals(result)) {
            ReusltStrDto reusltStrDto = JSON.parseObject(result, ReusltStrDto.class);
            if ("success".equals(reusltStrDto.getStatus())) {
                soSaleResultRootDto = resultDataHandle(reusltStrDto.getData());
                isSuccess = true;
            }
        }
        if (!isSuccess) {
            Assert.state(false, "代理品牌采购业务推送U8C采购订单失败 接口返回结果：{}", result);
        }
        return soSaleResultRootDto;
    }

    /**
     * 返回结果解析处理，在确认了success后调用
     *
     * @author liuyang
     */
    private SoSaleResultRootDto resultDataHandle(String resultData) {
        try {
            if (resultData != null && !"".equals(resultData)) {
                if (resultData.contains("[")) {
                    resultData = resultData.substring(1, resultData.length() - 1);
                }
                return JSON.parseObject(resultData, SoSaleResultRootDto.class);
            }
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("解析返回参数失败的错误", e);
            //如果解析失败，记录原因，但是不能影响结果的记录
        }
        return null;
    }
}